package A::B;

use strict;
use 5.008_005;
our $VERSION = '0.05';

1;
__END__

=encoding utf-8

=head1 NAME

A::B - Blah blah blah

=head1 SYNOPSIS

  use A::B;

=head1 DESCRIPTION

A::B is

=head1 AUTHOR

Yan Xueqing E<lt>yanxueqing621@163.comE<gt>

=head1 COPYRIGHT

Copyright 2017- Yan Xueqing

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 SEE ALSO

=cut
